/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWCAMP_CAMP_CUSTOMTYPE_HPP__
#define __FWCAMP_CAMP_CUSTOMTYPE_HPP__

namespace camp
{

enum CustomType
{
    mappingType = 0x404,
    pairType
};

} //camp

#endif /* __FWCAMP_CAMP_CUSTOMTYPE_HPP__ */
